from setuptools import setup

setup(name='gaussian_binomial_prob',
      version='0.1',
      description='Gaussian and Binomial distributions',
      packages=['gaussian_binomial_prob'],
      zip_safe=False)
